@@ -1,8 +1,9 @@
 f_control_mactivate <-
 function (param_sensitivity = 10^9, bool_free_w = FALSE, w0_seed = 0.10000000000000001, 
     max_internal_iter = 500, w_col_search = "one", bool_headStart = FALSE, 
-    ss_stop = 10^(-8), escape_rate = 1.004, step_size = 1/100, 
-    Wadj = 1/1, force_tries = 0, lambda = 0, tol = 10^(-8)) 
+    antifreeze = FALSE, ss_stop = 10^(-8), escape_rate = 1.004, 
+    step_size = 1/100, Wadj = 1/1, force_tries = 0, lambda = 0, 
+    tol = 10^(-8)) 
 {
     if (w_col_search == "one") {
         bool_fix_w <- TRUE
@@ -23,6 +24,7 @@ function (param_sensitivity = 10^9, bool_free_w = FALSE, w0_seed = 0.10000000000
     xls_out[["bool_fix_w"]] <- bool_fix_w
     xls_out[["bool_alt_w"]] <- bool_alt_w
     xls_out[["bool_headStart"]] <- bool_headStart
+    xls_out[["antifreeze"]] <- antifreeze
     xls_out[["ss_stop"]] <- ss_stop
     xls_out[["escape_rate"]] <- escape_rate
     xls_out[["step_size"]] <- step_size
